# coding: utf-8

# flake8: noqa
"""
    Buy Marketing API

    The Marketing API retrieves eBay products based on a metric, such as Best Selling, as well as products that were also bought and also viewed.  # noqa: E501

    OpenAPI spec version: v1_beta.2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

# import models into model package
from ...buy_marketing.models.amount import Amount
from ...buy_marketing.models.best_selling_product_response import BestSellingProductResponse
from ...buy_marketing.models.error import Error
from ...buy_marketing.models.error_parameter import ErrorParameter
from ...buy_marketing.models.image import Image
from ...buy_marketing.models.market_price_detail import MarketPriceDetail
from ...buy_marketing.models.merchandised_product import MerchandisedProduct
from ...buy_marketing.models.rating_aspect import RatingAspect
from ...buy_marketing.models.rating_aspect_distribution import RatingAspectDistribution
