# coding: utf-8

# flake8: noqa
"""
    Buy Offer API

    <span class=\"tablenote\"><b>Note:</b> This is a <a href=\"https://developer.ebay.com/api-docs/static/versioning.html#limited\" target=\"_blank\"> <img src=\"/cms/img/docs/partners-api.svg\" class=\"legend-icon partners-icon\" title=\"Limited Release\"  alt=\"Limited Release\" />(Limited Release)</a> API available only to select developers approved by business units.</span><br /><br />The Buy Offer API enables Partners to place proxy bids for a buyer and retrieve the auctions where the buyer is bidding.  By placing a proxy bid, the buyer is agreeing to purchase the item if they win the auction. </p>   # noqa: E501

    OpenAPI spec version: v1_beta.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

# import models into model package
from ...buy_offer.models.amount import Amount
from ...buy_offer.models.bidding import Bidding
from ...buy_offer.models.error import Error
from ...buy_offer.models.error_parameter import ErrorParameter
from ...buy_offer.models.place_proxy_bid_request import PlaceProxyBidRequest
from ...buy_offer.models.place_proxy_bid_response import PlaceProxyBidResponse
from ...buy_offer.models.proxy_bid import ProxyBid
from ...buy_offer.models.user_consent import UserConsent
